@@ -6,18 +6,25 @@ set -ev
 # And this script is called from the root directory.
 which scram
 which scram_tests
+which scram-gui
 
 scram_tests
 nosetests -w ./tests/
-
-if [[ -z "${RELEASE}" && "$CXX" = "g++" ]]; then
-  nosetests --with-coverage -w scripts test/
-fi
+(cd build && ctest --verbose)
 
 ./scripts/fault_tree_generator.py -b 200 -a 5
 scram --validate fault_tree.xml
 
 [[ "${TRAVIS_OS_NAME}" == "linux" ]] || exit 0
 
-LD_LIBRARY_PATH=${PWD}/install/lib/scram/test/:${LD_LIBRARY_PATH} \
-  scram --validate --allow-extern install/share/scram/input/model/system_extern_library.xml
+scram-gui --help
+scram-gui input/TwoTrain/two_train.xml&
+sleep 5
+kill $!
+
+if [[ "${CONFIG}" == "Coverage" ]]; then
+  nosetests --with-coverage -w scripts test/
+fi
+
+LD_LIBRARY_PATH=${PWD}/build/lib/scram/:${LD_LIBRARY_PATH} \
+  scram --validate --allow-extern tests/input/model/system_extern_library.xml
