@@ -15,7 +15,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/// @file analysis.cc
+/// @file
 /// Implementation of common facilities for all analysis classes.
 
 #include "analysis.h"
@@ -24,8 +24,7 @@ namespace scram {
 namespace core {
 
 Analysis::Analysis(Settings settings)
-    : settings_(std::move(settings)),
-      analysis_time_(0) {}
+    : settings_(std::move(settings)), analysis_time_(0) {}
 
 Analysis::~Analysis() = default;  ///< Pure virtual destructor.
 
