@@ -15,7 +15,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/// @file expression.cc
+/// @file
 /// Implementation of the expression base class.
 
 #include "expression.h"
@@ -26,9 +26,7 @@ namespace scram {
 namespace mef {
 
 Expression::Expression(std::vector<Expression*> args)
-    : args_(std::move(args)),
-      sampled_value_(0),
-      sampled_(false) {}
+    : args_(std::move(args)), sampled_value_(0), sampled_(false) {}
 
 double Expression::Sample() noexcept {
   if (!sampled_) {
