@@ -15,7 +15,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/// @file constant.cc
+/// @file
 /// Implementation of various constant expressions.
 
 #include "constant.h"
@@ -27,7 +27,7 @@ namespace mef {
 
 ConstantExpression ConstantExpression::kOne(1);
 ConstantExpression ConstantExpression::kZero(0);
-ConstantExpression ConstantExpression::kPi(
+ConstantExpression ConstantExpression::kPi(  // This line confuses some linters!
     boost::math::constants::pi<double>());
 
 }  // namespace mef
