@@ -15,7 +15,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/// @file parameter.cc
+/// @file
 /// Implementation of expression parameters.
 
 #include "parameter.h"
@@ -25,9 +25,7 @@
 namespace scram {
 namespace mef {
 
-MissionTime::MissionTime(double time, Units unit)
-    : unit_(unit),
-      value_(time) {
+MissionTime::MissionTime(double time, Units unit) : unit_(unit), value_(time) {
   value(time);
 }
 
