@@ -15,7 +15,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/// @file probability_analysis.cc
+/// @file
 /// Implementations of functions to provide
 /// probability analysis.
 
@@ -34,16 +34,14 @@ namespace core {
 
 ProbabilityAnalysis::ProbabilityAnalysis(const FaultTreeAnalysis* fta,
                                          mef::MissionTime* mission_time)
-    : Analysis(fta->settings()),
-      p_total_(0),
-      mission_time_(mission_time) {}
+    : Analysis(fta->settings()), p_total_(0), mission_time_(mission_time) {}
 
 void ProbabilityAnalysis::Analyze() noexcept {
   CLOCK(p_time);
   LOG(DEBUG3) << "Calculating probabilities...";
   // Get the total probability.
   p_total_ = this->CalculateTotalProbability();
-  assert(p_total_ >= 0 && p_total_ <= 1&& "The total probability is invalid.");
+  assert(p_total_ >= 0 && p_total_ <= 1 && "The total probability is invalid.");
   if (p_total_ == 1 &&
       Analysis::settings().approximation() != Approximation::kNone) {
     Analysis::AddWarning("Probability may have been adjusted to 1.");
@@ -108,7 +106,7 @@ void PartitionY(const Points& points, T* y_fractions) {
       if (p_0 <= b_0 && b_1 <= p_1)  // Sub-range.
         return (b_1 - b_0) / k;
       if (b_0 <= p_0 && p_1 <= b_1)  // Super-range.
-        return t_1 - t_0;            // Covers the case when k == 0.
+        return t_1 - t_0;  // Covers the case when k == 0.
       // The cases of partially overlapping intervals.
       if (p_0 <= b_0 && b_0 <= p_1)  // b_1 is outside (>) of the range.
         return (p_1 - b_0) / k;
@@ -138,11 +136,11 @@ void ProbabilityAnalysis::ComputeSil() noexcept {
   sil_ = std::make_unique<Sil>();
   if (p_time_.size() == 1) {
     sil_->pfd_avg = p_time_.front().first;
-    auto it = boost::find_if(
-        sil_->pfd_fractions,
-        [this](const std::pair<const double, double>& level) {
-          return sil_->pfd_avg <= level.first;
-        });
+    auto it =
+        boost::find_if(sil_->pfd_fractions,
+                       [this](const std::pair<const double, double>& level) {
+                         return sil_->pfd_avg <= level.first;
+                       });
     assert(it != sil_->pfd_fractions.end());
     it->second = 1;
   } else {
@@ -171,8 +169,7 @@ double CutSetProbabilityCalculator::Calculate(
 }
 
 double RareEventCalculator::Calculate(
-    const Zbdd& cut_sets,
-    const Pdag::IndexMap<double>& p_vars) noexcept {
+    const Zbdd& cut_sets, const Pdag::IndexMap<double>& p_vars) noexcept {
   double sum = 0;
   for (const std::vector<int>& cut_set : cut_sets) {
     sum += CutSetProbabilityCalculator::Calculate(cut_set, p_vars);
@@ -181,8 +178,7 @@ double RareEventCalculator::Calculate(
 }
 
 double McubCalculator::Calculate(
-    const Zbdd& cut_sets,
-    const Pdag::IndexMap<double>& p_vars) noexcept {
+    const Zbdd& cut_sets, const Pdag::IndexMap<double>& p_vars) noexcept {
   double m = 1;
   for (const std::vector<int>& cut_set : cut_sets) {
     m *= 1 - CutSetProbabilityCalculator::Calculate(cut_set, p_vars);
@@ -207,7 +203,7 @@ ProbabilityAnalyzerBase::CalculateProbabilityOverTime() noexcept {
          ProbabilityAnalysis::mission_time().value());
   double total_time = ProbabilityAnalysis::mission_time().value();
 
-  auto update = [this, &p_time] (double time) {
+  auto update = [this, &p_time](double time) {
     mission_time().value(time);
     auto it_p = p_vars_.begin();
     for (const mef::BasicEvent* event : graph_->basic_events())
@@ -223,8 +219,7 @@ ProbabilityAnalyzerBase::CalculateProbabilityOverTime() noexcept {
 
 ProbabilityAnalyzer<Bdd>::ProbabilityAnalyzer(FaultTreeAnalyzer<Bdd>* fta,
                                               mef::MissionTime* mission_time)
-    : ProbabilityAnalyzerBase(fta, mission_time),
-      owner_(false) {
+    : ProbabilityAnalyzerBase(fta, mission_time), owner_(false) {
   LOG(DEBUG2) << "Re-using BDD from FaultTreeAnalyzer for ProbabilityAnalyzer";
   bdd_graph_ = fta->algorithm();
   const Bdd::VertexPtr& root = bdd_graph_->root().vertex;
@@ -271,8 +266,7 @@ void ProbabilityAnalyzer<Bdd>::CreateBdd(
 }
 
 double ProbabilityAnalyzer<Bdd>::CalculateProbability(
-    const Bdd::VertexPtr& vertex,
-    bool mark,
+    const Bdd::VertexPtr& vertex, bool mark,
     const Pdag::IndexMap<double>& p_vars) noexcept {
   if (vertex->terminal())
     return 1;
