@@ -15,7 +15,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/// @file risk_analysis.cc
+/// @file
 /// Implementation of risk analysis handler.
 
 #include "risk_analysis.h"
@@ -89,9 +89,8 @@ void RiskAnalysis::RunAnalysis(boost::optional<Context> context) noexcept {
        model_->initiating_events()) {
     if (initiating_event->event_tree()) {
       LOG(INFO) << "Running event tree analysis: " << initiating_event->name();
-      auto eta = std::make_unique<EventTreeAnalysis>(*initiating_event,
-                                                     Analysis::settings(),
-                                                     model_->context());
+      auto eta = std::make_unique<EventTreeAnalysis>(
+          *initiating_event, Analysis::settings(), model_->context());
       eta->Analyze();
       for (EventTreeAnalysis::Result& result : eta->sequences()) {
         const mef::Sequence& sequence = result.sequence;
