@@ -29,7 +29,7 @@ TEST(FaultTreeTest, AddGate) {
   FaultTree ft("never_fail");
   Gate gate("Golden");
   EXPECT_NO_THROW(ft.Add(&gate));
-  EXPECT_THROW(ft.Add(&gate), ValidationError);  // Trying to re-add.
+  EXPECT_THROW(ft.Add(&gate), ValidityError);  // Trying to re-add.
 
   Gate gate_two("Iron");
   EXPECT_NO_THROW(ft.Add(&gate_two));  // No parent.
@@ -39,7 +39,7 @@ TEST(FaultTreeTest, AddBasicEvent) {
   FaultTree ft("never_fail");
   BasicEvent event("Golden");
   EXPECT_NO_THROW(ft.Add(&event));
-  EXPECT_THROW(ft.Add(&event), ValidationError);  // Trying to re-add.
+  EXPECT_THROW(ft.Add(&event), ValidityError);  // Trying to re-add.
 
   BasicEvent event_two("Iron");
   EXPECT_NO_THROW(ft.Add(&event_two));  // No parent.
@@ -49,7 +49,7 @@ TEST(FaultTreeTest, AddHouseEvent) {
   FaultTree ft("never_fail");
   HouseEvent event("Golden");
   EXPECT_NO_THROW(ft.Add(&event));
-  EXPECT_THROW(ft.Add(&event), ValidationError);  // Trying to re-add.
+  EXPECT_THROW(ft.Add(&event), ValidityError);  // Trying to re-add.
 
   HouseEvent event_two("Iron");
   EXPECT_NO_THROW(ft.Add(&event_two));  // No parent.
@@ -59,7 +59,7 @@ TEST(FaultTreeTest, AddCcfGroup) {
   FaultTree ft("never_fail");
   BetaFactorModel group("Golden");
   EXPECT_NO_THROW(ft.Add(&group));
-  EXPECT_THROW(ft.Add(&group), ValidationError);  // Trying to re-add.
+  EXPECT_THROW(ft.Add(&group), ValidityError);  // Trying to re-add.
 
   BetaFactorModel group_two("Iron");
   EXPECT_NO_THROW(ft.Add(&group_two));
@@ -69,7 +69,7 @@ TEST(FaultTreeTest, AddParameter) {
   FaultTree ft("never_fail");
   Parameter parameter("Golden");
   EXPECT_NO_THROW(ft.Add(&parameter));
-  EXPECT_THROW(ft.Add(&parameter), ValidationError);
+  EXPECT_THROW(ft.Add(&parameter), ValidityError);
 
   Parameter parameter_two("Iron");
   EXPECT_NO_THROW(ft.Add(&parameter_two));
