@@ -68,7 +68,7 @@ TEST(RegressionTest, ObjectSize) {
 // Tests the performance of probability calculations.
 TEST_F(PerformanceTest, DISABLED_ThreeMotor) {
   double p_time_std = 0.01;
-  std::string input = "./share/scram/input/ThreeMotor/three_motor.xml";
+  std::string input = "input/ThreeMotor/three_motor.xml";
   settings.probability_analysis(true);
   ASSERT_NO_THROW(Analyze({input}));
   EXPECT_LT(ProbabilityCalculationTime(), p_time_std);
@@ -77,8 +77,7 @@ TEST_F(PerformanceTest, DISABLED_ThreeMotor) {
 TEST_F(PerformanceTest, DISABLED_ChineseTree) {
   double mcs_time = 0.1;
   std::vector<std::string> input_files{
-      "./share/scram/input/Chinese/chinese.xml",
-      "./share/scram/input/Chinese/chinese-basic-events.xml"};
+      "input/Chinese/chinese.xml", "input/Chinese/chinese-basic-events.xml"};
   settings.probability_analysis(false);
   ASSERT_NO_THROW(Analyze(input_files));
   EXPECT_LT(ProductGenerationTime(), mcs_time);
@@ -86,7 +85,7 @@ TEST_F(PerformanceTest, DISABLED_ChineseTree) {
 
 TEST_F(PerformanceTest, DISABLED_200Event) {
   double mcs_time = 0.2;
-  std::string input = "./share/scram/input/Autogenerated/200_event.xml";
+  std::string input = "input/Autogenerated/200_event.xml";
   ASSERT_NO_THROW(Analyze({input}));
   EXPECT_EQ(15347, NumOfProducts());
   EXPECT_LT(ProductGenerationTime(), mcs_time);
@@ -97,9 +96,8 @@ TEST_F(PerformanceTest, DISABLED_Baobab1L7) {
 #ifdef NDEBUG
   mcs_time = 0.35;
 #endif
-  std::vector<std::string> input_files{
-      "./share/scram/input/Baobab/baobab1.xml",
-      "./share/scram/input/Baobab/baobab1-basic-events.xml"};
+  std::vector<std::string> input_files{"input/Baobab/baobab1.xml",
+                                       "input/Baobab/baobab1-basic-events.xml"};
   settings.limit_order(7);
   ASSERT_NO_THROW(Analyze(input_files));
   EXPECT_EQ(17432, NumOfProducts());
@@ -112,8 +110,7 @@ TEST_F(PerformanceTest, DISABLED_CEA9601_L4) {
   mcs_time = 2.0;
 #endif
   std::vector<std::string> input_files{
-      "./share/scram/input/CEA9601/CEA9601.xml",
-      "./share/scram/input/CEA9601/CEA9601-basic-events.xml"};
+      "input/CEA9601/CEA9601.xml", "input/CEA9601/CEA9601-basic-events.xml"};
   settings.limit_order(4).algorithm("bdd");
   ASSERT_NO_THROW(Analyze(input_files));
   EXPECT_EQ(54436, NumOfProducts());
@@ -124,8 +121,7 @@ TEST_F(PerformanceTest, DISABLED_CEA9601_L4) {
 TEST_F(PerformanceTest, DISABLED_CEA9601_L5) {
   double mcs_time = 3.8;
   std::vector<std::string> input_files{
-      "./share/scram/input/CEA9601/CEA9601.xml",
-      "./share/scram/input/CEA9601/CEA9601-basic-events.xml"};
+      "input/CEA9601/CEA9601.xml", "input/CEA9601/CEA9601-basic-events.xml"};
   settings.limit_order(5).algorithm("bdd");
   ASSERT_NO_THROW(Analyze(input_files));
   EXPECT_EQ(1615876, NumOfProducts());
@@ -135,8 +131,7 @@ TEST_F(PerformanceTest, DISABLED_CEA9601_L5) {
 TEST_F(PerformanceTest, DISABLED_CEA9601_L3_ZBDD) {
   double mcs_time = 1.5;
   std::vector<std::string> input_files{
-      "./share/scram/input/CEA9601/CEA9601.xml",
-      "./share/scram/input/CEA9601/CEA9601-basic-events.xml"};
+      "input/CEA9601/CEA9601.xml", "input/CEA9601/CEA9601-basic-events.xml"};
   settings.limit_order(3).algorithm("zbdd");
   ASSERT_NO_THROW(Analyze(input_files));
   EXPECT_EQ(1144, NumOfProducts());
@@ -146,9 +141,8 @@ TEST_F(PerformanceTest, DISABLED_CEA9601_L3_ZBDD) {
 
 TEST_F(PerformanceTest, DISABLED_Baobab2) {
   double mcs_time = 0.1;
-  std::vector<std::string> input_files{
-      "./share/scram/input/Baobab/baobab2.xml",
-      "./share/scram/input/Baobab/baobab2-basic-events.xml"};
+  std::vector<std::string> input_files{"input/Baobab/baobab2.xml",
+                                       "input/Baobab/baobab2-basic-events.xml"};
   ASSERT_NO_THROW(Analyze(input_files));
   EXPECT_EQ(4805, NumOfProducts());
   EXPECT_LT(ProductGenerationTime(), mcs_time);
@@ -159,9 +153,8 @@ TEST_F(PerformanceTest, DISABLED_Baobab1) {
 #ifdef NDEBUG
   mcs_time = 0.30;
 #endif
-  std::vector<std::string> input_files{
-      "./share/scram/input/Baobab/baobab1.xml",
-      "./share/scram/input/Baobab/baobab1-basic-events.xml"};
+  std::vector<std::string> input_files{"input/Baobab/baobab1.xml",
+                                       "input/Baobab/baobab1-basic-events.xml"};
   ASSERT_NO_THROW(Analyze(input_files));
   EXPECT_EQ(46188, NumOfProducts());
   EXPECT_NEAR(mcs_time, ProductGenerationTime(), mcs_time * delta);
@@ -172,9 +165,8 @@ TEST_F(PerformanceTest, DISABLED_Baobab1_ZBDD) {
 #ifdef NDEBUG
   mcs_time = 0.15;
 #endif
-  std::vector<std::string> input_files{
-      "./share/scram/input/Baobab/baobab1.xml",
-      "./share/scram/input/Baobab/baobab1-basic-events.xml"};
+  std::vector<std::string> input_files{"input/Baobab/baobab1.xml",
+                                       "input/Baobab/baobab1-basic-events.xml"};
   settings.algorithm("zbdd");
   ASSERT_NO_THROW(Analyze(input_files));
   EXPECT_EQ(46188, NumOfProducts());
