@@ -125,7 +125,7 @@ std::set<std::string> RiskAnalysisTest::Convert(const Product& product) {
 }
 
 TEST_F(RiskAnalysisTest, ProcessInput) {
-  std::string tree_input = "./share/scram/input/fta/correct_tree_input.xml";
+  std::string tree_input = "tests/input/fta/correct_tree_input.xml";
   ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
   EXPECT_EQ(3, gates().size());
   EXPECT_EQ(1, gates().count("TrainOne"));
@@ -159,8 +159,7 @@ TEST_F(RiskAnalysisTest, ProcessInput) {
 // Test Probability Assignment
 TEST_F(RiskAnalysisTest, PopulateProbabilities) {
   // Input with probabilities
-  std::string tree_input =
-      "./share/scram/input/fta/correct_tree_input_with_probs.xml";
+  std::string tree_input = "tests/input/fta/correct_tree_input_with_probs.xml";
   ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
   ASSERT_EQ(4, basic_events().size());
   ASSERT_EQ(1, basic_events().count("PumpOne"));
@@ -185,7 +184,7 @@ TEST_F(RiskAnalysisTest, PopulateProbabilities) {
 
 // Test Analysis of Two train system.
 TEST_P(RiskAnalysisTest, AnalyzeDefault) {
-  std::string tree_input = "./share/scram/input/fta/correct_tree_input.xml";
+  std::string tree_input = "tests/input/fta/correct_tree_input.xml";
   ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
   ASSERT_NO_THROW(analysis->Analyze());
   std::set<std::set<std::string>> mcs = {{"PumpOne", "PumpTwo"},
@@ -197,7 +196,7 @@ TEST_P(RiskAnalysisTest, AnalyzeDefault) {
 }
 
 TEST_P(RiskAnalysisTest, AnalyzeNonCoherentDefault) {
-  std::string tree_input = "./share/scram/input/fta/correct_non_coherent.xml";
+  std::string tree_input = "tests/input/fta/correct_non_coherent.xml";
   ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
   ASSERT_NO_THROW(analysis->Analyze());
   if (settings.prime_implicants()) {
@@ -209,16 +208,14 @@ TEST_P(RiskAnalysisTest, AnalyzeNonCoherentDefault) {
     EXPECT_EQ(5, products().size());
     EXPECT_EQ(pi, products());
   } else {
-    std::set<std::set<std::string>> mcs = {{"PumpOne", "PumpTwo"},
-                                           {"PumpOne", "ValveTwo"},
-                                           {"ValveOne"}};
+    std::set<std::set<std::string>> mcs = {
+        {"PumpOne", "PumpTwo"}, {"PumpOne", "ValveTwo"}, {"ValveOne"}};
     EXPECT_EQ(mcs, products());
   }
 }
 
 TEST_P(RiskAnalysisTest, AnalyzeWithProbability) {
-  std::string with_prob =
-      "./share/scram/input/fta/correct_tree_input_with_probs.xml";
+  std::string with_prob = "tests/input/fta/correct_tree_input_with_probs.xml";
   std::set<std::string> mcs_1 = {"PumpOne", "PumpTwo"};
   std::set<std::string> mcs_2 = {"PumpOne", "ValveTwo"};
   std::set<std::string> mcs_3 = {"PumpTwo", "ValveOne"};
@@ -243,8 +240,7 @@ TEST_P(RiskAnalysisTest, AnalyzeWithProbability) {
 // Test for exact probability calculation
 // regardless of the qualitative analysis algorithm.
 TEST_P(RiskAnalysisTest, EnforceExactProbability) {
-  std::string with_prob =
-      "./share/scram/input/fta/correct_tree_input_with_probs.xml";
+  std::string with_prob = "tests/input/fta/correct_tree_input_with_probs.xml";
   settings.probability_analysis(true).approximation("none");
   ASSERT_NO_THROW(ProcessInputFiles({with_prob}));
   ASSERT_NO_THROW(analysis->Analyze());
@@ -252,7 +248,7 @@ TEST_P(RiskAnalysisTest, EnforceExactProbability) {
 }
 
 TEST_P(RiskAnalysisTest, AnalyzeNestedFormula) {
-  std::string nested_input = "./share/scram/input/fta/nested_formula.xml";
+  std::string nested_input = "tests/input/fta/nested_formula.xml";
   std::set<std::set<std::string>> mcs = {{"PumpOne", "PumpTwo"},
                                          {"PumpOne", "ValveTwo"},
                                          {"PumpTwo", "ValveOne"},
@@ -263,8 +259,7 @@ TEST_P(RiskAnalysisTest, AnalyzeNestedFormula) {
 }
 
 TEST_F(RiskAnalysisTest, ImportanceDefault) {
-  std::string with_prob =
-      "./share/scram/input/fta/correct_tree_input_with_probs.xml";
+  std::string with_prob = "tests/input/fta/correct_tree_input_with_probs.xml";
   settings.importance_analysis(true);
   ASSERT_NO_THROW(ProcessInputFiles({with_prob}));
   ASSERT_NO_THROW(analysis->Analyze());
@@ -275,7 +270,7 @@ TEST_F(RiskAnalysisTest, ImportanceDefault) {
 }
 
 TEST_F(RiskAnalysisTest, ImportanceNeg) {
-  std::string tree_input = "./share/scram/input/fta/importance_neg_test.xml";
+  std::string tree_input = "tests/input/fta/importance_neg_test.xml";
   settings.prime_implicants(true).importance_analysis(true);
   ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
   ASSERT_NO_THROW(analysis->Analyze());
@@ -288,7 +283,7 @@ TEST_F(RiskAnalysisTest, ImportanceNeg) {
 }
 
 TEST_P(RiskAnalysisTest, ImportanceSingleEvent) {
-  std::string tree_input = "./share/scram/input/core/null_a.xml";
+  std::string tree_input = "tests/input/core/null_a.xml";
   settings.importance_analysis(true);
   ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
   ASSERT_NO_THROW(analysis->Analyze());
@@ -296,7 +291,7 @@ TEST_P(RiskAnalysisTest, ImportanceSingleEvent) {
 }
 
 TEST_P(RiskAnalysisTest, ImportanceZeroProbability) {
-  std::string tree_input = "./share/scram/input/core/zero_prob.xml";
+  std::string tree_input = "tests/input/core/zero_prob.xml";
   settings.importance_analysis(true);
   ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
   ASSERT_NO_THROW(analysis->Analyze());
@@ -304,7 +299,7 @@ TEST_P(RiskAnalysisTest, ImportanceZeroProbability) {
 }
 
 TEST_P(RiskAnalysisTest, ImportanceOneProbability) {
-  std::string tree_input = "./share/scram/input/core/one_prob.xml";
+  std::string tree_input = "tests/input/core/one_prob.xml";
   settings.importance_analysis(true);
   ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
   ASSERT_NO_THROW(analysis->Analyze());
@@ -313,7 +308,7 @@ TEST_P(RiskAnalysisTest, ImportanceOneProbability) {
 
 // Apply the rare event approximation.
 TEST_F(RiskAnalysisTest, ImportanceRareEvent) {
-  std::string with_prob = "./share/scram/input/fta/importance_test.xml";
+  std::string with_prob = "tests/input/fta/importance_test.xml";
   // Probability calculations with the rare event approximation.
   settings.approximation("rare-event").importance_analysis(true);
   ASSERT_NO_THROW(ProcessInputFiles({with_prob}));
@@ -327,8 +322,7 @@ TEST_F(RiskAnalysisTest, ImportanceRareEvent) {
 
 // Apply the minimal cut set upper bound approximation.
 TEST_F(RiskAnalysisTest, Mcub) {
-  std::string with_prob =
-      "./share/scram/input/fta/correct_tree_input_with_probs.xml";
+  std::string with_prob = "tests/input/fta/correct_tree_input_with_probs.xml";
   // Probability calculations with the MCUB approximation.
   settings.approximation("mcub").importance_analysis(true);
   ASSERT_NO_THROW(ProcessInputFiles({with_prob}));
@@ -339,7 +333,7 @@ TEST_F(RiskAnalysisTest, Mcub) {
 // Apply the minimal cut set upper bound approximation for non-coherent tree.
 // This should be a warning.
 TEST_F(RiskAnalysisTest, McubNonCoherent) {
-  std::string with_prob = "./share/scram/input/core/a_and_not_b.xml";
+  std::string with_prob = "tests/input/core/a_and_not_b.xml";
   // Probability calculations with the MCUB approximation.
   settings.approximation("mcub").probability_analysis(true);
   ASSERT_NO_THROW(ProcessInputFiles({with_prob}));
@@ -351,14 +345,13 @@ TEST_F(RiskAnalysisTest, McubNonCoherent) {
 /// @todo Expand this test.
 TEST_P(RiskAnalysisTest, AnalyzeMC) {
   settings.uncertainty_analysis(true);
-  std::string tree_input =
-      "./share/scram/input/fta/correct_tree_input_with_probs.xml";
+  std::string tree_input = "tests/input/fta/correct_tree_input_with_probs.xml";
   ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
   ASSERT_NO_THROW(analysis->Analyze());
 }
 
 TEST_P(RiskAnalysisTest, AnalyzeProbabilityOverTime) {
-  std::string tree_input = "./share/scram/input/core/single_exponential.xml";
+  std::string tree_input = "tests/input/core/single_exponential.xml";
   settings.probability_analysis(true).time_step(24).mission_time(120);
   std::vector<double> curve = {0,        2.399e-4, 4.7989e-4,
                                7.197e-4, 9.595e-4, 1.199e-3};
@@ -384,7 +377,7 @@ TEST_P(RiskAnalysisTest, AnalyzeProbabilityOverTime) {
 }
 
 TEST_P(RiskAnalysisTest, AnalyzeSil) {
-  std::string tree_input = "./share/scram/input/core/single_exponential.xml";
+  std::string tree_input = "tests/input/core/single_exponential.xml";
   settings.time_step(24).safety_integrity_levels(true);
   double pfd_fractions[] = {1.142e-4, 1.0275e-3, 1.02796e-2,
                             0.1033,   0.88527,   0};
@@ -412,7 +405,7 @@ TEST_P(RiskAnalysisTest, AnalyzeSil) {
 }
 
 TEST_P(RiskAnalysisTest, AnalyzeEventTree) {
-  const char* tree_input = "./share/scram/input/EventTrees/bcd.xml";
+  const char* tree_input = "input/EventTrees/bcd.xml";
   settings.probability_analysis(true);
   ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
   ASSERT_NO_THROW(analysis->Analyze());
@@ -428,7 +421,7 @@ TEST_P(RiskAnalysisTest, AnalyzeEventTree) {
 }
 
 TEST_P(RiskAnalysisTest, AnalyzeTestEventDefault) {
-  const char* tree_input = "./share/scram/input/eta/test_event_default.xml";
+  const char* tree_input = "tests/input/eta/test_event_default.xml";
   settings.probability_analysis(true);
   ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
   ASSERT_NO_THROW(analysis->Analyze());
@@ -440,7 +433,7 @@ TEST_P(RiskAnalysisTest, AnalyzeTestEventDefault) {
 }
 
 TEST_P(RiskAnalysisTest, AnalyzeTestInitatingEvent) {
-  const char* tree_input = "./share/scram/input/eta/test_initiating_event.xml";
+  const char* tree_input = "tests/input/eta/test_initiating_event.xml";
   settings.probability_analysis(true);
   ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
   ASSERT_NO_THROW(analysis->Analyze());
@@ -452,9 +445,8 @@ TEST_P(RiskAnalysisTest, AnalyzeTestInitatingEvent) {
 }
 
 TEST_P(RiskAnalysisTest, AnalyzeTestFunctionalEvent) {
-  const char* tree_input[] = {
-      "./share/scram/input/eta/test_functional_event.xml",
-      "./share/scram/input/eta/test_functional_event_link.xml"};
+  const char* tree_input[] = {"tests/input/eta/test_functional_event.xml",
+                              "tests/input/eta/test_functional_event_link.xml"};
   settings.probability_analysis(true);
   for (auto input : tree_input) {
     ASSERT_NO_THROW(ProcessInputFiles({input}));
@@ -471,7 +463,7 @@ TEST_P(RiskAnalysisTest, AnalyzeTestFunctionalEvent) {
 // Tests the output against the schema. However the contents of the
 // output are not verified or validated.
 TEST_F(RiskAnalysisTest, ReportIOError) {
-  std::string tree_input = "./share/scram/input/fta/correct_tree_input.xml";
+  std::string tree_input = "tests/input/fta/correct_tree_input.xml";
   // Messing up the output file.
   std::string output = "abracadabra.cadabraabra/output.txt";
   ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
@@ -480,119 +472,114 @@ TEST_F(RiskAnalysisTest, ReportIOError) {
 }
 
 TEST_F(RiskAnalysisTest, ReportEmpty) {
-  std::string tree_input = "./share/scram/input/empty_model.xml";
+  std::string tree_input = "tests/input/empty_model.xml";
   CheckReport({tree_input});
 }
 
 // Reporting of the default analysis for MCS only without probabilities.
 TEST_P(RiskAnalysisTest, ReportDefaultMCS) {
-  CheckReport({"./share/scram/input/fta/correct_tree_input.xml"});
+  CheckReport({"tests/input/fta/correct_tree_input.xml"});
 }
 
 // Reporting of analysis for MCS with probability results.
 TEST_F(RiskAnalysisTest, ReportProbability) {
-  std::string tree_input =
-      "./share/scram/input/fta/correct_tree_input_with_probs.xml";
+  std::string tree_input = "tests/input/fta/correct_tree_input_with_probs.xml";
   settings.probability_analysis(true);
   CheckReport({tree_input});
 }
 
 TEST_F(RiskAnalysisTest, ReportProbabilityCurve) {
-  std::string tree_input = "./share/scram/input/core/single_exponential.xml";
+  std::string tree_input = "tests/input/core/single_exponential.xml";
   settings.probability_analysis(true).time_step(24).mission_time(720);
   CheckReport({tree_input});
 }
 
 TEST_F(RiskAnalysisTest, ReportSil) {
-  std::string tree_input = "./share/scram/input/core/single_exponential.xml";
+  std::string tree_input = "tests/input/core/single_exponential.xml";
   settings.time_step(24).safety_integrity_levels(true).mission_time(720);
   CheckReport({tree_input});
 }
 
 // Reporting of importance analysis.
 TEST_F(RiskAnalysisTest, ReportImportanceFactors) {
-  std::string tree_input =
-      "./share/scram/input/fta/correct_tree_input_with_probs.xml";
+  std::string tree_input = "tests/input/fta/correct_tree_input_with_probs.xml";
   settings.importance_analysis(true);
   CheckReport({tree_input});
 }
 
 // Reporting of uncertainty analysis.
 TEST_F(RiskAnalysisTest, ReportUncertaintyResults) {
-  std::string tree_input =
-      "./share/scram/input/fta/correct_tree_input_with_probs.xml";
+  std::string tree_input = "tests/input/fta/correct_tree_input_with_probs.xml";
   settings.uncertainty_analysis(true);
   CheckReport({tree_input});
 }
 
 // Reporting event tree analysis with an initiating event.
 TEST_F(RiskAnalysisTest, ReportInitiatingEventAnalysis) {
-  const char* tree_input = "./share/scram/input/EventTrees/bcd.xml";
+  const char* tree_input = "input/EventTrees/bcd.xml";
   settings.probability_analysis(true);
   CheckReport({tree_input});
 }
 
 // Reporting of CCF analysis.
 TEST_F(RiskAnalysisTest, ReportCCF) {
-  std::string tree_input = "./share/scram/input/core/mgl_ccf.xml";
+  std::string tree_input = "tests/input/core/mgl_ccf.xml";
   settings.ccf_analysis(true).importance_analysis(true);
   CheckReport({tree_input});
 }
 
 // Reporting of Negative events in MCS.
 TEST_F(RiskAnalysisTest, ReportNegativeEvent) {
-  std::string tree_input = "./share/scram/input/core/a_or_not_b.xml";
+  std::string tree_input = "tests/input/core/a_or_not_b.xml";
   settings.probability_analysis(true);
   CheckReport({tree_input});
 }
 
 // Reporting of all possible analyses.
 TEST_F(RiskAnalysisTest, ReportAll) {
-  std::string tree_input =
-      "./share/scram/input/fta/correct_tree_input_with_probs.xml";
-  settings.importance_analysis(true).uncertainty_analysis(true)
-      .ccf_analysis(true);
+  std::string tree_input = "tests/input/fta/correct_tree_input_with_probs.xml";
+  settings.importance_analysis(true).uncertainty_analysis(true).ccf_analysis(
+      true);
   CheckReport({tree_input});
 }
 
 // Reporting with public or private roles.
 TEST_F(RiskAnalysisTest, ReportRoles) {
-  std::string tree_input = "./share/scram/input/fta/mixed_roles.xml";
+  std::string tree_input = "tests/input/fta/mixed_roles.xml";
   CheckReport({tree_input});
 }
 
 // Reporting of orphan primary events.
 TEST_F(RiskAnalysisTest, ReportOrphanPrimaryEvents) {
-  std::string tree_input = "./share/scram/input/fta/orphan_primary_event.xml";
+  std::string tree_input = "tests/input/fta/orphan_primary_event.xml";
   CheckReport({tree_input});
 }
 
 // Reporting of unused parameters.
 TEST_F(RiskAnalysisTest, ReportUnusedParameters) {
-  std::string tree_input = "./share/scram/input/fta/unused_parameter.xml";
+  std::string tree_input = "tests/input/fta/unused_parameter.xml";
   CheckReport({tree_input});
 }
 
 TEST_F(RiskAnalysisTest, ReportUnusedEventTreeElements) {
-  std::string tree_input = "./share/scram/input/eta/unused_elements.xml";
+  std::string tree_input = "tests/input/eta/unused_elements.xml";
   CheckReport({tree_input});
 }
 
 TEST_F(RiskAnalysisTest, ReportAlignment) {
-  std::string tree_input =
-      "./share/scram/input/TwoTrain/two_train_alignment.xml";
+  std::string tree_input = "input/TwoTrain/two_train_alignment.xml";
   CheckReport({tree_input});
 }
 
 TEST_F(RiskAnalysisTest, ReportAlignmentEventTree) {
-  std::string dir = "./share/scram/input/EventTrees/";
+  std::string dir = "input/EventTrees/";
   settings.probability_analysis(true);
   CheckReport({dir + "attack_alignment.xml", dir + "attack.xml"});
 }
 
 // NAND and NOR as a child cases.
 TEST_P(RiskAnalysisTest, ChildNandNorGates) {
-  std::string tree_input = "./share/scram/input/fta/children_nand_nor.xml";
+  std::string tree_input = "tests/input/fta/children_nand_nor.xml";
   ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
   ASSERT_NO_THROW(analysis->Analyze());
   if (settings.prime_implicants()) {
@@ -607,7 +594,7 @@ TEST_P(RiskAnalysisTest, ChildNandNorGates) {
 
 // Simple test for several house event propagation.
 TEST_P(RiskAnalysisTest, ManyHouseEvents) {
-  std::string tree_input = "./share/scram/input/fta/constant_propagation.xml";
+  std::string tree_input = "tests/input/fta/constant_propagation.xml";
   ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
   ASSERT_NO_THROW(analysis->Analyze());
   std::set<std::set<std::string>> mcs = {{"A", "B"}};
@@ -616,7 +603,7 @@ TEST_P(RiskAnalysisTest, ManyHouseEvents) {
 
 // Simple test for several constant gate propagation.
 TEST_P(RiskAnalysisTest, ConstantGates) {
-  std::string tree_input = "./share/scram/input/fta/constant_gates.xml";
+  std::string tree_input = "tests/input/fta/constant_gates.xml";
   ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
   ASSERT_NO_THROW(analysis->Analyze());
   EXPECT_EQ(kUnity, products());
@@ -624,8 +611,7 @@ TEST_P(RiskAnalysisTest, ConstantGates) {
 
 // Mixed roles with undefined event types
 TEST_F(RiskAnalysisTest, UndefinedEventsMixedRoles) {
-  std::string tree_input =
-      "./share/scram/input/fta/ambiguous_events_with_roles.xml";
+  std::string tree_input = "tests/input/fta/ambiguous_events_with_roles.xml";
   ASSERT_NO_THROW(ProcessInputFiles({tree_input}));
   ASSERT_NO_THROW(analysis->Analyze());
   std::set<std::set<std::string>> mcs = {
@@ -636,8 +622,7 @@ TEST_F(RiskAnalysisTest, UndefinedEventsMixedRoles) {
 
 // Extern function call check.
 TEST_P(RiskAnalysisTest, ExternFunctionProbability) {
-  std::string tree_input =
-      "./share/scram/input/model/extern_full_check.xml";
+  std::string tree_input = "tests/input/model/extern_full_check.xml";
   settings.probability_analysis(true);
   ASSERT_NO_THROW(ProcessInputFiles({tree_input}, true));
   ASSERT_NO_THROW(analysis->Analyze());
